@@ -20,7 +20,7 @@ from .helpers import (
 )
 
 
-_GOOGLE_ADS_VERSION = "v7"
+_GOOGLE_ADS_VERSION = "v9"
 
 
 class Client():
@@ -46,7 +46,7 @@ def get_google_ads_client(
     """Initialize google ads client depending on arguments furnished
     Priority order is: creator_email (obtained with google_ads_account/google_ads_account_id/user_email) > credentials_path
     Args:
-        mcc_credentials_path (str): mcc credentials. Defaults to None.
+        mcc_credentials_path (str): arcane mcc credentials. Defaults to None.
         google_ads_account (Optional[Dict], optional): Account for which we want to init google ads client. Defaults to None.
         base_account (Optional[BaseAccount], optional): Account information needed to get the account for which we want to init google ads client. Defaults to None.
         clients_service_url: (Optional[str], optional): Needed for getting goolge ads account if not provided. Defaults to None.
@@ -100,9 +100,9 @@ def get_google_ads_client(
                 ),
                 creator_email=creator_email
             )
-        return Client(GoogleAdsClient.load_from_storage(mcc_credentials_path))
+        return get_gads_client_initialized_with_arcane_mcc_credentials(mcc_credentials_path)
     elif mcc_credentials_path:
-        return Client(GoogleAdsClient.load_from_storage(mcc_credentials_path))
+        return get_gads_client_initialized_with_arcane_mcc_credentials(mcc_credentials_path)
     else:
         raise BadRequestError('one of the following arguments must be specified: mcc_credentials_path and (google_ads_account or base_account or user_email)')
 
@@ -122,7 +122,8 @@ def check_access_account(
     datastore_client: Optional[DatastoreClient] = None,
     gcp_project: Optional[str] = None,
     secret_key_file: Optional[str] = None,
-    client: Optional[Client] = None
+    client: Optional[Client] = None,
+    mcc_account_allowed: Optional[bool] = False
 ):
     """Check if we can access to an GAdsAccount stored in database
 
@@ -137,11 +138,14 @@ def check_access_account(
         gcp_project: (Optional[str], optional): Needed for get_google_ads_client. Defaults to None.
         secret_key_file: (Optional[str], optional): Needed for get_google_ads_client. Defaults to None.
         client: (Optional[Client], optional): google ads client if already initialized
+        mcc_account_allowed: (Optional[bool], optional): Make mcc account accepted only when the client is given. Defaults to False.
     Raises:
         BadRequestError: Raised when arguments are not good
         GoogleAdsAccountNoAccessException: Raised when we have no access
     """
     if not client:
+        if mcc_account_allowed:
+            raise BadRequestError('mcc_account_allowed is not handled when client is not given')
         if google_ads_account is None:
             if base_account is None:
                 raise BadRequestError('google_ads_account and base_account should not be None simultanelously')
@@ -174,12 +178,12 @@ def check_access_account(
                     raise BadRequestError('base_account should not be None when google ads client is given')
         account_id = base_account['id']
     try:
-        _check_access_account_lgq(account_id, google_ads_client)
+        _check_access_account_lgq(account_id, google_ads_client, mcc_account_allowed)
     except GoogleAdsAccountNoAccessException:
         if creator_email:
             message = f"{creator_email} has no longer access to this account."
         else:
-            message = "Arcane's Google Ads Manager Account no longer has access to this account."
+            message = "Arcane's Google Ads Manager Account can not access this account."
         raise GoogleAdsAccountNoAccessException(message)
     except (ServiceUnavailable, RefreshError) as err:
         if 'Token has been expired' in str(err) and creator_email:
@@ -187,7 +191,6 @@ def check_access_account(
         raise
 
 
-
 def check_access_before_creation(
     account_id: str,
     user_email: str,
@@ -269,7 +272,11 @@ def check_access_before_creation(
             "You don't have access to this Google Ads account, you cannot link it to SmartFeeds. Please ask someone else who have access to do the linking")
 
 
-def _check_access_account_lgq(google_ads_account_id: str, google_ads_client: GoogleAdsClient):
+def _check_access_account_lgq(
+    google_ads_account_id: str,
+    google_ads_client: GoogleAdsClient,
+    mcc_account_allowed: Optional[bool] = False
+):
     try:
         customers = get_customer(google_ads_account_id, google_ads_client)
         if len(customers) == 0:
@@ -290,7 +297,7 @@ def _check_access_account_lgq(google_ads_account_id: str, google_ads_client: Goo
             raise GoogleAdsAccountException(
                 f"This Account is not enabled ({google_ads_account_id}).")
         raise
-    if customer_resp.customer.manager:
+    if not mcc_account_allowed and customer_resp.customer.manager:
         raise GoogleAdsAccountException(
             'This account ID is a MCC. Please enter a Google Ads Account.')
 
@@ -313,3 +320,15 @@ def get_customer(google_ads_account_id: str, google_ads_client: GoogleAdsClient)
     search_query.customer_id = account_id
     search_query.query = query
     return list(google_ads_service.search(search_query))
+
+
+def get_gads_client_initialized_with_arcane_mcc_credentials(mcc_credentials_path: str) -> Client:
+    """Init a gads client with arcane mcc credentials
+
+    Args:
+        mcc_credentials_path (str): arcane mcc credentials.
+
+    Returns:
+        Client
+    """
+    return Client(GoogleAdsClient.load_from_storage(mcc_credentials_path))
