@@ -5,3 +5,7 @@ class GoogleAdsAccountNoAccessException(Exception):
 class GoogleAdsAccountException(Exception):
     """ Raised when a google ads error has occured expect user permission denied"""
     pass
+
+class EmptyCredentialsError(Exception):
+    """ Raised when empty credentials are provided"""
+    pass
